%
%   =====================================================================
%   Copyright (C) 2018  Peer Neubert, peer.neubert@etit.tu-chemnitz.de
%   
%   This program is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%   
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%   
%   You should have received a copy of the GNU General Public License
%   along with this program.  If not, see <http://www.gnu.org/licenses/>.
%   =====================================================================
%
% Software release for the paper:
% "A Sequence-Based Neuronal Model for Mobile Robot Localization"
% Peer Neubert, Subutai Ahmad, and Peter Protzel, Proc. of German 
% Conference on Artificial Intelligence, 2018 
%
% Create result plots from the paper
function createFigure()

    fs = 16;
    lw = 3;
    ms = 10;
    cm = colormap(lines);
    
    % randomized connections
    figure();
    set(gca, 'fontsize', fs);
    preparePlot(fs);    
        
    load('results/pr_multiloop_p005.mat', 'P1', 'R1');
    h_p005 = plot(R1, P1, ':',  'linewidth', lw, 'markersize', ms); 
    
    load('results/pr_multiloop_p001.mat', 'P1', 'R1');
    h_p001 = plot(R1, P1, '--', 'linewidth', lw, 'markersize', ms); 
    
    load('results/pr_multiloop_p0.mat', 'P1', 'R1');
    h_p0 = plot(R1, P1, '-', 'linewidth', lw, 'markersize', ms); 
    
    legend([h_p0 h_p001 h_p005], {'SHOSM (p=0)', 'rSHOSM p=0.01', 'rSHOSM p=0.05'}, 'location', 'southwest', 'fontsize', fs);
    
    % comparison to baseline
    figure();
    set(gca, 'fontsize', fs);
    preparePlot(fs);    
        
    load('results/pr_multiloop_noise0_al1_hosm.mat', 'P1', 'R1');
    load('results/pr_multiloop_noise0_al1_pairs.mat', 'P2', 'R2');
    h_1a = plot(R1, P1, '-',  'linewidth', lw, 'color', cm(3,:)); 
    h_1b = plot(R2, P2, ':',  'linewidth', lw, 'color', cm(3,:)); 
        
    load('results/pr_multiloop_noise01_al0_hosm.mat', 'P1', 'R1');
    load('results/pr_multiloop_noise01_al0_pairs.mat', 'P2', 'R2');
    h_2a = plot(R1, P1, '--',  'linewidth', lw, 'color', cm(2,:)); 
    h_2b = plot(R2, P2, ':',  'linewidth', lw, 'color', cm(2,:));     
    
    load('results/pr_multiloop_noise05_al5_hosm.mat', 'P1', 'R1');
    load('results/pr_multiloop_noise05_al5_pairs.mat', 'P2', 'R2');
    h_3a = plot(R1, P1, '-',  'linewidth', lw, 'color', cm(1,:)); 
    h_3b = plot(R2, P2, ':',  'linewidth', lw, 'color', cm(1,:)); 
    
    legend([h_1a h_1b h_2a h_2b h_3a h_3b], {'rSHOSM a=1, n=0%', 'Pairs a=1, n=0%', 'rSHOSM a=0, n=10%', 'Pairs a=0, n=10%', 'rSHOSM a=5, n=50%', 'Pairs a=5, n=50%'}, 'location', 'southwest', 'fontsize', fs);
    
end

function preparePlot(fs)
    xlabel('Recall', 'fontsize', fs);
    ylabel('Precision', 'fontsize', fs);
    axis equal
    axis([0 1 0 1]);
    hold all;
end